==> zio-aws-emr_2.12-5.17.129.3-sources.jar: zio/aws/emr/model/ClusterSummary.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.{
  OptionalArnType,
  ArnType,
  Integer,
  ClusterId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClusterSummary(
    id: Option[ClusterId] = None,
    name: Option[String] = None,
    status: Option[zio.aws.emr.model.ClusterStatus] = None,
    normalizedInstanceHours: Option[Integer] = None,
    clusterArn: Option[ArnType] = None,
    outpostArn: Option[OptionalArnType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ClusterSummary = {
    import ClusterSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ClusterSummary
      .builder()
      .optionallyWith(
        id.map(value => ClusterId.unwrap(value): java.lang.String)
      )(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .optionallyWith(
        normalizedInstanceHours.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.normalizedInstanceHours)
      .optionallyWith(
        clusterArn.map(value => ArnType.unwrap(value): java.lang.String)
      )(_.clusterArn)
      .optionallyWith(
        outpostArn.map(value => OptionalArnType.unwrap(value): java.lang.String)
      )(_.outpostArn)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ClusterSummary.ReadOnly =
    zio.aws.emr.model.ClusterSummary.wrap(buildAwsValue())
}
object ClusterSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.ClusterSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ClusterSummary =
      zio.aws.emr.model.ClusterSummary(
        id.map(value => value),
        name.map(value => value),
        status.map(value => value.asEditable),
        normalizedInstanceHours.map(value => value),
        clusterArn.map(value => value),
        outpostArn.map(value => value)
      )
    def id: Option[ClusterId]
    def name: Option[String]
    def status: Option[zio.aws.emr.model.ClusterStatus.ReadOnly]
    def normalizedInstanceHours: Option[Integer]
    def clusterArn: Option[ArnType]
    def outpostArn: Option[OptionalArnType]
    def getId: ZIO[Any, AwsError, ClusterId] =
      AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.emr.model.ClusterStatus.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
    def getNormalizedInstanceHours: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("normalizedInstanceHours", normalizedInstanceHours)
    def getClusterArn: ZIO[Any, AwsError, ArnType] =
      AwsError.unwrapOptionField("clusterArn", clusterArn)
    def getOutpostArn: ZIO[Any, AwsError, OptionalArnType] =
      AwsError.unwrapOptionField("outpostArn", outpostArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ClusterSummary
  ) extends zio.aws.emr.model.ClusterSummary.ReadOnly {
    override val id: Option[ClusterId] = scala
      .Option(impl.id())
      .map(value => zio.aws.emr.model.primitives.ClusterId(value))
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val status: Option[zio.aws.emr.model.ClusterStatus.ReadOnly] =
      scala
        .Option(impl.status())
        .map(value => zio.aws.emr.model.ClusterStatus.wrap(value))
    override val normalizedInstanceHours: Option[Integer] = scala
      .Option(impl.normalizedInstanceHours())
      .map(value => zio.aws.emr.model.primitives.Integer(value))
    override val clusterArn: Option[ArnType] = scala
      .Option(impl.clusterArn())
      .map(value => zio.aws.emr.model.primitives.ArnType(value))
    override val outpostArn: Option[OptionalArnType] = scala
      .Option(impl.outpostArn())
      .map(value => zio.aws.emr.model.primitives.OptionalArnType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ClusterSummary
  ): zio.aws.emr.model.ClusterSummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-emr_2.12-5.17.157.2-sources.jar: zio/aws/emr/model/ClusterSummary.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.{
  OptionalArnType,
  ArnType,
  Integer,
  ClusterId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClusterSummary(
    id: Option[ClusterId] = None,
    name: Option[String] = None,
    status: Option[zio.aws.emr.model.ClusterStatus] = None,
    normalizedInstanceHours: Option[Integer] = None,
    clusterArn: Option[ArnType] = None,
    outpostArn: Option[OptionalArnType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ClusterSummary = {
    import ClusterSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ClusterSummary
      .builder()
      .optionallyWith(
        id.map(value => ClusterId.unwrap(value): java.lang.String)
      )(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .optionallyWith(
        normalizedInstanceHours.map(value => value: java.lang.Integer)
      )(_.normalizedInstanceHours)
      .optionallyWith(
        clusterArn.map(value => ArnType.unwrap(value): java.lang.String)
      )(_.clusterArn)
      .optionallyWith(
        outpostArn.map(value => OptionalArnType.unwrap(value): java.lang.String)
      )(_.outpostArn)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ClusterSummary.ReadOnly =
    zio.aws.emr.model.ClusterSummary.wrap(buildAwsValue())
}
object ClusterSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.ClusterSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ClusterSummary =
      zio.aws.emr.model.ClusterSummary(
        id.map(value => value),
        name.map(value => value),
        status.map(value => value.asEditable),
        normalizedInstanceHours.map(value => value),
        clusterArn.map(value => value),
        outpostArn.map(value => value)
      )
    def id: Option[ClusterId]
    def name: Option[String]
    def status: Option[zio.aws.emr.model.ClusterStatus.ReadOnly]
    def normalizedInstanceHours: Option[Integer]
    def clusterArn: Option[ArnType]
    def outpostArn: Option[OptionalArnType]
    def getId: ZIO[Any, AwsError, ClusterId] =
      AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.emr.model.ClusterStatus.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
    def getNormalizedInstanceHours: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("normalizedInstanceHours", normalizedInstanceHours)
    def getClusterArn: ZIO[Any, AwsError, ArnType] =
      AwsError.unwrapOptionField("clusterArn", clusterArn)
    def getOutpostArn: ZIO[Any, AwsError, OptionalArnType] =
      AwsError.unwrapOptionField("outpostArn", outpostArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ClusterSummary
  ) extends zio.aws.emr.model.ClusterSummary.ReadOnly {
    override val id: Option[ClusterId] = scala
      .Option(impl.id())
      .map(value => zio.aws.emr.model.primitives.ClusterId(value))
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val status: Option[zio.aws.emr.model.ClusterStatus.ReadOnly] =
      scala
        .Option(impl.status())
        .map(value => zio.aws.emr.model.ClusterStatus.wrap(value))
    override val normalizedInstanceHours: Option[Integer] =
      scala.Option(impl.normalizedInstanceHours()).map(value => value: Integer)
    override val clusterArn: Option[ArnType] = scala
      .Option(impl.clusterArn())
      .map(value => zio.aws.emr.model.primitives.ArnType(value))
    override val outpostArn: Option[OptionalArnType] = scala
      .Option(impl.outpostArn())
      .map(value => zio.aws.emr.model.primitives.OptionalArnType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ClusterSummary
  ): zio.aws.emr.model.ClusterSummary.ReadOnly = new Wrapper(impl)
}
